==> kdepim-4.14.2.tar.xz: kdepim-4.14.2/libksieve/ksieveui/vacation/multiimapvacationdialog.h <==
/*
  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MULTIIMAPVACATIONDIALOG_H
#define MULTIIMAPVACATIONDIALOG_H

#include <KDialog>

#include "ksieveui_export.h"

class KTabWidget;
class QStackedWidget;
namespace KSieveUi {
class VacationCreateScriptJob;
class KSIEVEUI_EXPORT MultiImapVacationDialog : public KDialog
{
    Q_OBJECT
public:
    explicit MultiImapVacationDialog(QWidget *parent=0);
    ~MultiImapVacationDialog();

    QList<VacationCreateScriptJob *> listCreateJob() const;

    void switchToServerNamePage(const QString &serverName);

private slots:
    void slotOkClicked();    
    void slotDefaultClicked();

private:
    void createPage(const QString &serverName, const KUrl &url);
    void init();
    void readConfig();
    void writeConfig();
    QList<VacationCreateScriptJob *> mListCreateJob;
    KTabWidget *mTabWidget;
    QStackedWidget *mStackedWidget;
};
}

#endif // MULTIIMAPVACATIONDIALOG_H

==> kdepim-15.08.0.tar.xz: kdepim-15.08.0/libksieve/ksieveui/vacation/multiimapvacationdialog.h <==
/*
  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MULTIIMAPVACATIONDIALOG_H
#define MULTIIMAPVACATIONDIALOG_H

#include <QDialog>
#include <QUrl>
#include "ksieveui_export.h"

class QTabWidget;
class QStackedWidget;
namespace KSieveUi
{
class VacationCreateScriptJob;
class KSIEVEUI_EXPORT MultiImapVacationDialog : public QDialog
{
    Q_OBJECT
public:
    explicit MultiImapVacationDialog(QWidget *parent = Q_NULLPTR);
    ~MultiImapVacationDialog();

    QList<VacationCreateScriptJob *> listCreateJob() const;

    void switchToServerNamePage(const QString &serverName);

Q_SIGNALS:
    void okClicked();
    void cancelClicked();

private Q_SLOTS:
    void slotOkClicked();
    void slotDefaultClicked();
    void slotCanceled();

private:
    void createPage(const QString &serverName, const QUrl &url);
    void init();
    void readConfig();
    void writeConfig();
    QList<VacationCreateScriptJob *> mListCreateJob;
    QTabWidget *mTabWidget;
    QStackedWidget *mStackedWidget;
};
}

#endif // MULTIIMAPVACATIONDIALOG_H
